LiquidGlassPlayerPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • LiquidGlassPlayerPlatform
Implementers

Constructors

LiquidGlassPlayerPlatform()
Constructs a LiquidGlassPlayerPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance LiquidGlassPlayerPlatform
The default instance of LiquidGlassPlayerPlatform to use.
getter/setter pair